/*
 * "Small Hello World" example.
 *
 * This example prints 'Hello from Nios II' to the STDOUT stream. It runs on
 * the Nios II 'standard', 'full_featured', 'fast', and 'low_cost' example
 * designs. It requires a STDOUT  device in your system's hardware.
 *
 * The purpose of this example is to demonstrate the smallest possible Hello
 * World application, using the Nios II HAL library.  The memory footprint
 * of this hosted application is ~332 bytes by default using the standard
 * reference design.  For a more fully featured Hello World application
 * example, see the example titled "Hello World".
 *
 * The memory footprint of this example has been reduced by making the
 * following changes to the normal "Hello World" example.
 * Check in the Nios II Software Developers Manual for a more complete
 * description.
 *
 * In the SW Application project (small_hello_world):
 *
 *  - In the C/C++ Build page
 *
 *    - Set the Optimization Level to -Os
 *
 * In System Library project (small_hello_world_syslib):
 *  - In the C/C++ Build page
 *
 *    - Set the Optimization Level to -Os
 *
 *    - Define the preprocessor option ALT_NO_INSTRUCTION_EMULATION
 *      This removes software exception handling, which means that you cannot
 *      run code compiled for Nios II cpu with a hardware multiplier on a core
 *      without a the multiply unit. Check the Nios II Software Developers
 *      Manual for more details.
 *
 *  - In the System Library page:
 *    - Set Periodic system timer and Timestamp timer to none
 *      This prevents the automatic inclusion of the timer driver.
 *
 *    - Set Max file descriptors to 4
 *      This reduces the size of the file handle pool.
 *
 *    - Check Main function does not exit
 *    - Uncheck Clean exit (flush buffers)
 *      This removes the unneeded call to exit when main returns, since it
 *      won't.
 *
 *    - Check Don't use C++
 *      This builds without the C++ support code.
 *
 *    - Check Small C library
 *      This uses a reduced functionality C library, which lacks
 *      support for buffering, file IO, floating point and getch(), etc.
 *      Check the Nios II Software Developers Manual for a complete list.
 *
 *    - Check Reduced device drivers
 *      This uses reduced functionality drivers if they're available. For the
 *      standard design this means you get polled UART and JTAG UART drivers,
 *      no support for the LCD driver and you lose the ability to program
 *      CFI compliant flash devices.
 *
 *    - Check Access device drivers directly
 *      This bypasses the device file system to access device drivers directly.
 *      This eliminates the space required for the device file system services.
 *      It also provides a HAL version of libc services that access the drivers
 *      directly, further reducing space. Only a limited number of libc
 *      functions are available in this configuration.
 *
 *    - Use ALT versions of stdio routines:
 *
 *           Function                  Description
 *        ===============  =====================================
 *        alt_printf       Only supports %s, %x, and %c ( < 1 Kbyte)
 *        alt_putstr       Smaller overhead than puts with direct drivers
 *                         Note this function doesn't add a newline.
 *        alt_putchar      Smaller overhead than putchar with direct drivers
 *        alt_getchar      Smaller overhead than getchar with direct drivers
 *
 */

#include "sys/alt_stdio.h"
#include "system.h"       //VXȅAx[XAhXȂ
#include "sys/alt_irq.h"  //荞ݗpwb_t@C
#include "Altera_avalon_pio_regs.h"  //HALɓo^ĂPIOpwb_t@C
#include "user_blk_regs.h" //[U[Hpwb_t@C

int main()
{

	  int rd_data;
	  int rd_data_hold;
	  alt_putstr("Hello from Nios II!\n");
	  /* Event loop never exits. */
	  while (1){
        rd_data = IORD_USER_BLK_DATA(USER_BLK_0_BASE); //ǂݏo
        IOWR_ALTERA_AVALON_PIO_DATA(PIO_0_BASE, rd_data); //
        if (rd_data!=rd_data_hold){
        	if ((rd_data&01)==0x00)
        		alt_printf("start \n");
        	if ((rd_data&02)==0x0)
        		alt_printf("lap %x%x.%x%x%xS\n",IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x38)
	                                           ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x34)
        				                       ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x30)
        				                       ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x2c)
        				                       ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x28));
        	if ((rd_data&04)==0x0)
        		alt_printf("stop %x%x.%x%x%xS\n",IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x38)
	                                           ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x34)
        				                       ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x30)
        				                       ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x2c)
        				                       ,IORD_USER_BLK_DATA(USER_BLK_0_BASE+0x38));
        }
        rd_data_hold = rd_data;
	  };
	  return 0;

	/*
  alt_putstr("Hello from Nios II!\n");
  */
  /* Event loop never exits. */
  while (1);

  return 0;
}
